@@ -3,5 +3,5 @@ use crossterm::event::{KeyCode, KeyModifiers, MouseEvent};
 #[derive(Debug, Clone, Copy)]
 pub enum InputMessages {
     ButtonPress((KeyCode, KeyModifiers)),
-    MouseEvent(MouseEvent),
+    MouseEvent((MouseEvent, KeyModifiers)),
 }
